.. _rconf-reference-patch:

Patch
========================================================================

.. automodule:: rconf.patch
    :noindex:


Patch
------------------------------------------------------------------------

.. autoclass:: rconf.patch.PatchOperation
    :members:

.. autoclass:: rconf.patch.PatchOperationObject
    :members:

.. autoclass:: rconf.patch.Patch
    :members:


Exceptions
------------------------------------------------------------------------

.. autoclass:: rconf.patch.PatchError

.. autoclass:: rconf.patch.PatchTestError

.. autoclass:: rconf.patch.PatchValueError

.. autoclass:: rconf.patch.PatchLookupError

.. autoclass:: rconf.patch.PatchIndexError

.. autoclass:: rconf.patch.PatchKeyError
